@@ -17,6 +17,14 @@
 #'   is in [0, 1] and color is a character string indicating the
 #'   color of the darken.  0 indicates no darkening, 1 indicates a
 #'   black-out.
+#' @param b Deprecated, renamed to `padding`. Overrides any
+#'   `padding` argument.
+#' @param fullpage Deprecated, equivalent to `extent = "device"`
+#'   when `TRUE`. Overrides any `extent` argument.
+#' @param expand Deprecated, equivalent to `extent = "panel"`
+#'   when `TRUE` and `fullpage` is `FALSE`. When `fullpage`
+#'   is `FALSE` and `expand` is `FALSE`, equivalent to
+#'   `extent="normal"`. Overrides any `extent` argument.
 #' @param ... ...
 #' @return a ggplot object
 #' @author David Kahle \email{david.kahle@@gmail.com}
@@ -24,7 +32,7 @@
 #' @export ggmap inset inset_raster
 #' @examples
 #'
-#' \dontrun{ map queries drag R CMD check
+#' \dontrun{## map queries drag R CMD check
 #'
 #'
 #' ## extents and legends
@@ -96,9 +104,7 @@
 #'
 #' # again, qmplot is probably more useful
 #' qmplot(lon, lat, data = points, color = class, darken = .4, alpha = I(.6))
-#' qmplot(lon, lat, data = points, color = class, darken = 0,
-#'   maptype = "toner-lite"
-#' )
+#' qmplot(lon, lat, data = points, color = class, maptype = "toner-lite")
 #'
 #' ## cool examples
 #' ##################################################
@@ -110,32 +116,29 @@
 #'
 #' # adding additional content
 #' library(grid)
-#' baylor <- get_map("baylor university", zoom = 15, maptype = "satellite")
+#' baylor <- get_map("one bear place, waco, texas", zoom = 15, maptype = "satellite")
 #' ggmap(baylor)
 #'
 #' # use gglocator to find lon/lat"s of interest
-#' (clicks <- clicks <- gglocator(2) )
+#' (clicks <- gglocator(2) )
+#' ggmap(baylor) +
+#'   geom_point(aes(x = lon, y = lat), data = clicks, colour = "red", alpha = .5)
 #' expand.grid(lon = clicks$lon, lat = clicks$lat)
 #'
 #' ggmap(baylor) + theme_bw() +
 #'   annotate("segment", x=-97.110, xend=-97.1188, y=31.5450, yend=31.5485,
 #'     colour=I("red"), arrow = arrow(length=unit(0.3,"cm")), size = 1.5) +
-#'   annotate("rect", xmin=-97.122, ymin=31.5439, xmax=-97.1050, ymax=31.5452,
-#'     fill = I("white"), alpha = I(3/4)) +
-#'   annotate("text", x=-97.113, y=31.5445, label = "Department of Statistical Science",
+#'   annotate("label", x=-97.113, y=31.5445, label = "Department of Statistical Science",
 #'     colour = I("red"), size = 3.5) +
 #'   labs(x = "Longitude", y = "Latitude") + ggtitle("Baylor University")
 #'
 #'
-#'
-#' baylor <- get_map("baylor university", zoom = 16, maptype = "satellite")
+#' baylor <- get_map("marrs mclean science, waco, texas", zoom = 16, maptype = "satellite")
 #'
 #' ggmap(baylor, extent = "panel") +
 #'   annotate("segment", x=-97.1175, xend=-97.1188, y=31.5449, yend=31.5485,
 #'     colour=I("red"), arrow = arrow(length=unit(0.4,"cm")), size = 1.5) +
-#'   annotate("rect", xmin=-97.122, ymin=31.5441, xmax=-97.113, ymax=31.5449,
-#'     fill = I("white"), alpha = I(3/4)) +
-#'   annotate("text", x=-97.1175, y=31.5445, label = "Department of Statistical Science",
+#'   annotate("label", x=-97.1175, y=31.5447, label = "Department of Statistical Science",
 #'     colour = I("red"), size = 4)
 #'
 #'
@@ -199,8 +202,8 @@
 #' # the bubble chart
 #' HoustonMap +
 #'    geom_point(aes(x = lon, y = lat, colour = offense, size = offense), data = violent_crimes) +
-#'    scale_colour_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder")) +
-#'    scale_size_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder"),
+#'    scale_colour_discrete("Offense", labels = c("Robbery","Aggravated Assault","Rape","Murder")) +
+#'    scale_size_discrete("Offense", labels = c("Robbery","Aggravated Assault","Rape","Murder"),
 #'      range = c(1.75,6)) +
 #'    guides(size = guide_legend(override.aes = list(size = 6))) +
 #'    theme(
@@ -220,8 +223,8 @@
 #' qmplot(lon, lat, data = violent_crimes, maptype = "toner-lite",
 #'   color = offense, size = offense, legend = "topleft"
 #' ) +
-#'   scale_colour_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder")) +
-#'   scale_size_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder"),
+#'   scale_colour_discrete("Offense", labels = c("Robbery","Aggravated Assault","Rape","Murder")) +
+#'   scale_size_discrete("Offense", labels = c("Robbery","Aggravated Assault","Rape","Murder"),
 #'     range = c(1.75,6)) +
 #'   guides(size = guide_legend(override.aes = list(size = 6))) +
 #'   theme(
@@ -240,7 +243,7 @@
 #' HoustonMap +
 #'   stat_density2d(aes(x = lon, y = lat, colour = offense),
 #'     size = 3, bins = 2, alpha = 3/4, data = violent_crimes) +
-#'    scale_colour_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder")) +
+#'    scale_colour_discrete("Offense", labels = c("Robbery","Aggravated Assault","Rape","Murder")) +
 #'    theme(
 #'      legend.text = element_text(size = 15, vjust = .5),
 #'      legend.title = element_text(size = 15,face="bold"),
@@ -251,12 +254,12 @@
 #'
 #' # 2d histogram...
 #' HoustonMap +
-#'   stat_bin2d(aes(x = lon, y = lat, colour = offense, fill = offense),
+#'   stat_bin_2d(aes(x = lon, y = lat, colour = offense, fill = offense),
 #'     size = .5, bins = 30, alpha = 2/4, data = violent_crimes) +
 #'    scale_colour_discrete("Offense",
-#'      labels = c("Robery","Aggravated Assault","Rape","Murder"),
+#'      labels = c("Robbery","Aggravated Assault","Rape","Murder"),
 #'      guide = FALSE) +
-#'    scale_fill_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder")) +
+#'    scale_fill_discrete("Offense", labels = c("Robbery","Aggravated Assault","Rape","Murder")) +
 #'    theme(
 #'      legend.text = element_text(size = 15, vjust = .5),
 #'      legend.title = element_text(size = 15,face="bold"),
@@ -264,19 +267,6 @@
 #'    )
 #'
 #'
-#' # ... with hexagonal bins
-#' HoustonMap +
-#'   stat_binhex(aes(x = lon, y = lat, colour = offense, fill = offense),
-#'     size = .5, binwidth = c(.00225,.00225), alpha = 2/4, data = violent_crimes) +
-#'    scale_colour_discrete("Offense",
-#'      labels = c("Robery","Aggravated Assault","Rape","Murder"),
-#'      guide = FALSE) +
-#'    scale_fill_discrete("Offense", labels = c("Robery","Aggravated Assault","Rape","Murder")) +
-#'    theme(
-#'      legend.text = element_text(size = 15, vjust = .5),
-#'      legend.title = element_text(size = 15,face="bold"),
-#'      legend.key.size = grid::unit(1.8,"lines")
-#'    )
 #'
 #'
 #'
@@ -297,6 +287,7 @@
 #' overlay <- stat_density2d(aes(x = lon, y = lat, fill = ..level.., alpha = ..level..),
 #'     bins = 4, geom = "polygon", data = violent_crimes)
 #'
+#' attr(houston,"bb") # to help finding (x/y)(min/max) vals below
 #'
 #' HoustonMap +
 #'   stat_density2d(aes(x = lon, y = lat, fill = ..level.., alpha = ..level..),
@@ -310,12 +301,8 @@
 #'       scale_alpha(range = c(.4, .75), guide = FALSE) +
 #'       theme_inset()
 #'     ),
-#'     xmin = attr(houston,"bb")$ll.lon +
-#'       (7/10) * (attr(houston,"bb")$ur.lon - attr(houston,"bb")$ll.lon),
-#'     xmax = Inf,
-#'     ymin = -Inf,
-#'     ymax = attr(houston,"bb")$ll.lat +
-#'       (3/10) * (attr(houston,"bb")$ur.lat - attr(houston,"bb")$ll.lat)
+#'     xmin = -95.35877, xmax = -95.34229,
+#'     ymin = 29.73754, ymax = 29.75185
 #'   )
 #'
 #'
@@ -445,7 +432,7 @@
 #'
 #' }
 ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
-  legend = "right", padding = .02, darken = c(0, "black"), ...)
+  legend = "right", padding = .02, darken = c(0, "black"), b, fullpage, expand, ...)
 {
 
   # dummies to trick R CMD check
@@ -454,22 +441,16 @@ ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
   ll.lat <- NULL; rm(ll.lat); ur.lat <- NULL; rm(ur.lat);
 
   # deprecated syntaxes
-  args <- as.list(match.call(expand.dots = TRUE)[-1])
-  if("ggmapplot" %in% names(args)){
-    .Deprecated(msg = "ggmaplot syntax deprecated, use ggmap.")
-  }
-
-  if("b" %in% names(args)){
+  if(!missing(b)) {
     .Deprecated(msg = "b syntax deprecated, use padding.")
-    b <- NULL; rm(b);
-    padding <- eval(args$b)
+    padding <- b
   }
 
-  if("fullpage" %in% names(args) || "expand" %in% names(args)){
+  if(!missing(fullpage) || !missing(expand)){
     .Deprecated(msg = "fullpage and expand syntaxes deprecated, use extent.")
-    if("fullpage" %in% names(args)){fullpage <- eval(args$fullpage)}else{fullpage <- FALSE}
+    if(missing(fullpage)) { fullpage <- FALSE }
+    if(missing(expand)) { expand <- FALSE }
     if(fullpage) extent <- "device"
-    if("expand" %in% names(args)){expand <- eval(args$expand)}else{expand <- FALSE}
     if(fullpage == FALSE && expand == TRUE) extent <- "panel"
     if(fullpage == FALSE && expand == FALSE) extent <- "normal"
   }
@@ -524,19 +505,23 @@ ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
     args <- as.list(match.call()[-1])
     base <- deparse(args$base_layer) # "ggplot(aes(), data = blah)"
     # if passed from another function
-    if(base == "base_layer") base <- deparse(eval(args$base_layer))
+    if(base[1] == "base_layer") base <- deparse(eval(args$base_layer))
 
     # shorthand notation
     xmin <- attr(ggmap, "bb")$ll.lon
     xmax <- attr(ggmap, "bb")$ur.lon
   	ymin <- attr(ggmap, "bb")$ll.lat
   	ymax <- attr(ggmap, "bb")$ur.lat
-    str2parse <- paste(base, "geom_blank()",
+    str2parse <- paste(paste(base, collapse = ""), "geom_blank()",
       "inset_raster(ggmap, xmin, xmax, ymin, ymax)",
       sep = " + "
     )
 
-    p <- eval(parse(text = str2parse))
+    # attempt to ensure that base_layer argument is evaluated correctly by forcing evaluation in the calling environment.
+    # if that fails, the previous default behavior is provided. see https://github.com/dkahle/ggmap/issues/84 for background.
+    p <- try(eval(parse(text = paste(base,collapse="")),parent.frame(1))+geom_blank()+inset_raster(ggmap, xmin, xmax, ymin, ymax))
+    if(inherits(p,"try-error")) p <- eval(parse(text = str2parse))
+
     p <- p + annotate("rect", xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax,
   	  fill = darken[2], alpha = as.numeric(darken[1]))
   }
@@ -545,7 +530,7 @@ ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
   if(maprange) p <- p + xlim(xmin, xmax) + ylim(ymin, ymax)
 
   # set scales
-  p <- p + coord_map(projection = "mercator")
+  p <- p + coord_map2()
 
   # set extent
   xmin <- attr(ggmap, "bb")$ll.lon
@@ -620,6 +605,7 @@ ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
 ggmapplot <- function(ggmap, fullpage = FALSE,
   base_layer, maprange = FALSE, expand = FALSE, ...)
 {
+  .Deprecated(msg = "ggmapplot syntax deprecated, use ggmap.")
   ggmap(ggmap, fullpage = fullpage, base_layer = base_layer,
     maprange = FALSE, expand = FALSE, ggmapplot = TRUE)
 }
