@@ -12,26 +12,23 @@
 #' @export
 #' @examples
 #'
-#' \dontrun{
-#' # these examples have been excluded for checking efficiency
+#' \dontrun{ some requires Google API key; heavy network/time load
 #'
-#' qmap(location = "baylor university")
-#' qmap(location = "baylor university", zoom = 14)
-#' qmap(location = "baylor university", zoom = 14, source = "osm")
-#' qmap(location = "baylor university", zoom = 14, source = "osm", scale = 20000)
-#' qmap(location = "baylor university", zoom = 14, maptype = "satellite")
-#' qmap(location = "baylor university", zoom = 14, maptype = "hybrid")
-#' qmap(location = "baylor university", zoom = 14, maptype = "toner", source = "stamen")
-#' qmap(location = "baylor university", zoom = 14, maptype = "watercolor", source = "stamen")
-#' qmap(location = "baylor university", zoom = 14, maptype = "terrain-background", source = "stamen")
-#' qmap(location = "baylor university", zoom = 14, maptype = "toner-lite", source = "stamen")
+#' location <- "marrs mclean science, waco, texas"
+#' qmap(location)
+#' qmap(location, zoom = 14)
+#' qmap(location, zoom = 14, source = "osm")
+#' qmap(location, zoom = 14, source = "osm", scale = 20000)
+#' qmap(location, zoom = 14, maptype = "satellite")
+#' qmap(location, zoom = 14, maptype = "hybrid")
+#' qmap(location, zoom = 14, maptype = "toner", source = "stamen")
+#' qmap(location, zoom = 14, maptype = "watercolor", source = "stamen")
+#' qmap(location, zoom = 14, maptype = "terrain-background", source = "stamen")
+#' qmap(location, zoom = 14, maptype = "toner-lite", source = "stamen")
 #'
-#' api_key <- "<your api key here>"
-#' qmap(location = "baylor university", zoom = 14, maptype = 15434,
-#'   source = "cloudmade", api_key = api_key)
-#'
-#' wh <- geocode("the white house")
-#' qmap("the white house", maprange = TRUE,
+#' where <- "the white house, washington dc"
+#' wh <- geocode(where)
+#' qmap(where, maprange = TRUE, zoom = 15,
 #'   base_layer = ggplot(aes(x=lon, y=lat), data = wh)) +
 #'   geom_point()
 #'
@@ -44,15 +41,15 @@ qmap <- function(location = "houston", ...){
   # location formatting
   location_stop <- TRUE
   if(is.character(location) && length(location) == 1){
-    location_type <- "address"
+    # address
     location_stop <- FALSE
   }
   if(is.numeric(location) && length(location) == 2){
-    location_type <- "lonlat"
+    # lonlat
     location_stop <- FALSE
   }
   if(is.numeric(location) && length(location) == 4){
-    location_type <- "bbox"
+    # bbox
     location_stop <- FALSE
   }
   if(location_stop){
@@ -76,24 +73,6 @@ qmap <- function(location = "houston", ...){
   	scale <- "auto"
   }
 
-  if("messaging" %in% names(args)){
-    messaging <- eval(args$messaging)
-  } else {
-    messaging <- FALSE
-  }
-
-  if("urlonly" %in% names(args)){
-    urlonly <- eval(args$urlonly)
-  } else {
-    urlonly <- FALSE
-  }
-
-  if("filename" %in% names(args)){
-    filename <- eval(args$filename)
-  } else {
-    filename <- "ggmapTemp"
-  }
-
   if("color" %in% names(args)){
     color <- eval(args$color)
   } else {
@@ -126,25 +105,6 @@ qmap <- function(location = "houston", ...){
     }
   }
 
-  if("crop" %in% names(args)){
-    crop <- eval(args$crop)
-  } else {
-    crop <- TRUE
-  }
-
-  if("api_key" %in% names(args)){
-    api_key <- eval(args$api_key)
-  } else {
-    if(source == "cloudmade"){
-      stop("an api key must be specified for cloudmade maps, see ?get_cloudmademap.",
-      call. = F)
-    }
-    api_key <- NULL
-  }
-
-
-
-
   # ggmap args
   ##################
 
@@ -196,7 +156,7 @@ qmap <- function(location = "houston", ...){
   # return
   ggmap(
     get_map(location = location, zoom = zoom, scale = scale, source = source,
-      color = color, maptype = maptype, language = language, api_key = api_key, force = force),
+      color = color, maptype = maptype, language = language, force = force),
     maprange = maprange, extent = extent, base_layer = base_layer, legend = legend,
       padding = padding, darken = darken
   )
