@@ -37,17 +37,12 @@
 #' }
 #'
 theme_inset <- function (base_size = 12){
-  t <- theme_get()
-  t$axis.line <- element_blank()
-  t$axis.text.x <- element_blank()
-  t$axis.text.y <- element_blank()
-  t$axis.ticks <- element_blank()
-  t$axis.title.x <- element_blank()
-  t$axis.title.y <- element_blank()
-  t$axis.ticks.length <- unit(0, "lines")
-  t$axis.ticks.margin <- unit(0, "lines")
-  t$panel.margin <- unit(0, "lines")
-  t$plot.margin <- unit(c(0, 0, 0, 0), "lines")
-  t$legend.position <- 'none'
-  t
+  theme(axis.line         = element_blank(),
+        axis.text         = element_blank(),
+        axis.ticks        = element_blank(),
+        axis.title        = element_blank(),
+        axis.ticks.length = unit(0, "lines"),
+        panel.spacing     = unit(0, "lines"),
+        plot.margin       = unit(c(0, 0, 0, 0), "lines"),
+        legend.position   = 'none')
 }
